@@ -971,6 +971,8 @@ startElement(void *ctx, const xmlChar *fullname, const xmlChar **atts)
 	      "Validation failed: no DTD found !\n");
 	}
 	ctxt->validate = 0;
+	ctxt->valid = 0;
+	ctxt->errNo = XML_ERR_NO_DTD;
     }
        
 
@@ -1132,7 +1134,13 @@ startElement(void *ctx, const xmlChar *fullname, const xmlChar **atts)
 	    ctxt->sax->warning(ctxt->userData, 
 		 "Namespace prefix %s is not defined\n", prefix);
     }
-    xmlSetNs(ret, ns);
+
+    /*
+     * set the namespace node, making sure that if the default namspace
+     * is unbound on a parent we simply kee it NULL
+     */
+    if ((ns != NULL) && (ns->href[0] != 0))
+	xmlSetNs(ret, ns);
 
     /*
      * process all the other attributes
@@ -1258,7 +1266,6 @@ reference(void *ctx, const xmlChar *name)
  * @len: the number of xmlChar
  *
  * receiving some chars from the parser.
- * Question: how much at a time ???
  */
 void
 characters(void *ctx, const xmlChar *ch, int len)
@@ -1364,7 +1371,7 @@ characters(void *ctx, const xmlChar *ch, int len)
  * @len: the number of xmlChar
  *
  * receiving some ignorable whitespaces from the parser.
- * Question: how much at a time ???
+ * UNUSED: by default the DOM building will use characters
  */
 void
 ignorableWhitespace(void *ctx ATTRIBUTE_UNUSED, const xmlChar *ch ATTRIBUTE_UNUSED, int len ATTRIBUTE_UNUSED)
@@ -1682,7 +1689,7 @@ xmlSAXHandler xmlDefaultSAXHandler = {
     endElement,
     reference,
     characters,
-    ignorableWhitespace,
+    characters,
     processingInstruction,
     comment,
     xmlParserWarning,
@@ -1726,7 +1733,7 @@ xmlDefaultSAXHandlerInit(void)
     xmlDefaultSAXHandler.reference = reference;
     xmlDefaultSAXHandler.characters = characters;
     xmlDefaultSAXHandler.cdataBlock = cdataBlock;
-    xmlDefaultSAXHandler.ignorableWhitespace = ignorableWhitespace;
+    xmlDefaultSAXHandler.ignorableWhitespace = characters;
     xmlDefaultSAXHandler.processingInstruction = processingInstruction;
     xmlDefaultSAXHandler.comment = comment;
     if (xmlGetWarningsDefaultValue == 0)
