@@ -217,6 +217,7 @@ struct _xmlParserCtxt {
 
     int                loadsubset;    /* should the external subset be loaded */
     int                linenumbers;   /* set line number in element content */
+    void              *catalogs;       /* document's own catalog */
 };
 
 /**
@@ -471,18 +472,18 @@ int		xmlParseBalancedChunkMemory(xmlDocPtr doc,
 					 void *user_data,
 					 int depth,
 					 const xmlChar *string,
-					 xmlNodePtr *list);
+					 xmlNodePtr *lst);
 int		xmlParseExternalEntity	(xmlDocPtr doc,
 					 xmlSAXHandlerPtr sax,
 					 void *user_data,
 					 int depth,
 					 const xmlChar *URL,
 					 const xmlChar *ID,
-					 xmlNodePtr *list);
+					 xmlNodePtr *lst);
 int		xmlParseCtxtExternalEntity(xmlParserCtxtPtr ctx,
 					 const xmlChar *URL,
 					 const xmlChar *ID,
-					 xmlNodePtr *list);
+					 xmlNodePtr *lst);
 
 /*
  * SAX initialization routines
