@@ -415,7 +415,9 @@ xmlNanoHTTPSend(xmlNanoHTTPCtxtPtr ctxt, const char * xmt_ptr, int outlen) {
             if (nsent>0)
                 total_sent += nsent;
 	    else if ( ( nsent == -1 ) && 
+#if defined(EAGAIN) && EAGAIN != EWOULDBLOCK
 	    	      ( socket_errno( ) != EAGAIN ) &&
+#endif
 		        ( socket_errno( ) != EWOULDBLOCK ) ) {
 	        xmlGenericError( xmlGenericErrorContext,
 				"xmlNanoHTTPSend error:  %s",
@@ -540,7 +542,11 @@ xmlNanoHTTPRecv(xmlNanoHTTPCtxtPtr ctxt) {
 	FD_ZERO(&rfd);
 	FD_SET(ctxt->fd, &rfd);
 	
-	if ( (select(ctxt->fd+1, &rfd, NULL, NULL, &tv)<1) && (errno != EINTR) )
+	if ( (select(ctxt->fd+1, &rfd, NULL, NULL, &tv)<1)
+#if defined(EINTR)
+		&& (errno != EINTR)
+#endif
+	)
 		return(0);
     }
     return(0);
@@ -1312,7 +1318,7 @@ xmlNanoHTTPFetch(const char *URL, const char *filename, char **contentType) {
  */
 int
 xmlNanoHTTPSave(void *ctxt, const char *filename) {
-    char buf[4096];
+    char *buf = NULL;
     int fd;
     int len;
     
